==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/General/fileops/translations/fileops_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="98"/>
        <location filename="../fileops.cpp" line="132"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="99"/>
        <location filename="../fileops.cpp" line="133"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>מדור יעד לא קיים</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="136"/>
        <source>Move Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="137"/>
        <source>Are you sure you want to move %n file(s)?</source>
        <translation>
            <numerusform>האם אתה בטוח כי ברצונך להעביר קובץ %n?</numerusform>
            <numerusform>האם אתה בטוח כי ברצונך להעביר %n קבצים?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="153"/>
        <source>Copying</source>
        <translation>העתקה</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="154"/>
        <location filename="../fileops.cpp" line="244"/>
        <source>Stop</source>
        <translation>הפסק</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="199"/>
        <source>Copying file %1/%2</source>
        <translation>העתקת קובץ %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="243"/>
        <source>Moving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="276"/>
        <source>Moving file %1/%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="114"/>
        <source>Remove Files</source>
        <translation>הסר קבצים</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="115"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation>
            <numerusform>האם אתה בטוח כי ברצונך להסיר קובץ %n מתוך הכונן?</numerusform>
            <numerusform>האם אתה בטוח כי ברצונך להסיר %n קבצים מתוך הכונן?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="30"/>
        <source>File Operations Plugin</source>
        <translation>תוסף מבצעי קובץ</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="50"/>
        <source>About File Operations Plugin</source>
        <translation>אודות תוסף מבצעי קובץ</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>תוסף מבצעי קובץ של Qmmp</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חובר על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>התאמת קיצור דרך</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>הזן את צירוף המקש אשר ברצונך להקצות</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>טהר</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>הגדרות מבצעי קובץ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Enabled</source>
        <translation>מאופשר</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Operation</source>
        <translation>מבצע</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Menu text</source>
        <translation>תמליל תפריט</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Shortcut</source>
        <translation>קיצור דרך</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Add</source>
        <translation>הוסף</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <location filename="../settingsdialog.cpp" line="54"/>
        <location filename="../settingsdialog.cpp" line="134"/>
        <source>Remove</source>
        <translation>הסר</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Destination:</source>
        <translation>יעד:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="126"/>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>File name pattern:</source>
        <translation>תבנית שם קובץ:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="51"/>
        <location filename="../settingsdialog.cpp" line="131"/>
        <source>Copy</source>
        <translation>העתק</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Rename</source>
        <translation>שנה שם</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="137"/>
        <source>New action</source>
        <translation>פעולה חדשה</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="220"/>
        <source>Artist</source>
        <translation>אמן</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="221"/>
        <source>Album</source>
        <translation>אלבום</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="222"/>
        <source>Album Artist</source>
        <translation>אמן אלבום</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="223"/>
        <source>Title</source>
        <translation>כותרת</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="224"/>
        <source>Track Number</source>
        <translation>מספר רצועה</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="225"/>
        <source>Two-digit Track Number</source>
        <translation>מספר רצועה דו ספרתי</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="230"/>
        <source>Disc Number</source>
        <translation>מספר תקליטור</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="231"/>
        <source>File Name</source>
        <translation>שם קובץ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="232"/>
        <source>File Path</source>
        <translation>נתיב קובץ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="226"/>
        <source>Genre</source>
        <translation>ז׳אנר</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="227"/>
        <source>Comment</source>
        <translation>הערה</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="228"/>
        <source>Composer</source>
        <translation>מלחין</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="229"/>
        <source>Duration</source>
        <translation>משך</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="233"/>
        <source>Year</source>
        <translation>שנה</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="234"/>
        <source>Condition</source>
        <translation>תנאי</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="247"/>
        <source>Choose a directory</source>
        <translation>בחר מדור</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/General/fileops/translations/fileops_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="98"/>
        <location filename="../fileops.cpp" line="132"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="99"/>
        <location filename="../fileops.cpp" line="133"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>מדור יעד לא קיים</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="136"/>
        <source>Move Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="137"/>
        <source>Are you sure you want to move %n file(s)?</source>
        <translation>
            <numerusform>האם אתה בטוח כי ברצונך להעביר קובץ %n?</numerusform>
            <numerusform>האם אתה בטוח כי ברצונך להעביר %n קבצים?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="153"/>
        <source>Copying</source>
        <translation>העתקה</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="154"/>
        <location filename="../fileops.cpp" line="244"/>
        <source>Stop</source>
        <translation>הפסק</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="199"/>
        <source>Copying file %1/%2</source>
        <translation>העתקת קובץ %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="243"/>
        <source>Moving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="276"/>
        <source>Moving file %1/%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="114"/>
        <source>Remove Files</source>
        <translation>הסר קבצים</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="115"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation>
            <numerusform>האם אתה בטוח כי ברצונך להסיר קובץ %n מתוך הכונן?</numerusform>
            <numerusform>האם אתה בטוח כי ברצונך להסיר %n קבצים מתוך הכונן?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="30"/>
        <source>File Operations Plugin</source>
        <translation>תוסף מבצעי קובץ</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="50"/>
        <source>About File Operations Plugin</source>
        <translation>אודות תוסף מבצעי קובץ</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>תוסף מבצעי קובץ של Qmmp</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>התאמת קיצור דרך</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>הזן את צירוף המקש אשר ברצונך להקצות</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>טהר</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>הגדרות מבצעי קובץ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Enabled</source>
        <translation>מאופשר</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Operation</source>
        <translation>מבצע</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Menu text</source>
        <translation>תמליל תפריט</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Shortcut</source>
        <translation>קיצור דרך</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Add</source>
        <translation>הוסף</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <location filename="../settingsdialog.cpp" line="54"/>
        <location filename="../settingsdialog.cpp" line="134"/>
        <source>Remove</source>
        <translation>הסר</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Destination:</source>
        <translation>יעד:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="126"/>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>File name pattern:</source>
        <translation>תבנית שם קובץ:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="51"/>
        <location filename="../settingsdialog.cpp" line="131"/>
        <source>Copy</source>
        <translation>העתק</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Rename</source>
        <translation>שנה שם</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="137"/>
        <source>New action</source>
        <translation>פעולה חדשה</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="232"/>
        <source>Choose a directory</source>
        <translation>בחר מדור</translation>
    </message>
</context>
</TS>
